==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/wm_import.js <==
function wm_import(){
	this.xmlns = 'import';
};

wm_import.inherit(wm_generic);
var _me = wm_import.prototype;

//********************************************************************************
//********************************************************************************
_me.import_data = function(aData)
{
	var aRequest = {'IMPORT':[{'ATTRIBUTES':{'ACTION':aData.action},'ACCOUNT':[{'ATTRIBUTES':{'UID':aData.account}}],'FULLPATH':[{'VALUE':aData.path}]}]};

    if (aData.action != 'groupware'){
		//Lines in case of CSV
		if (aData.action == 'csv'){
			if (aData.lines)
				aRequest.IMPORT[0].LINES = [{VALUE:aData.lines}];

			if (aData.skipfirst)
				aRequest.IMPORT[0].SKIPFIRST = [{VALUE:'true'}];

			if (aData.values){
				aRequest.ACCOUNT = [{ATTRIBUTES:{UID:aData.account},FOLDER:[{ATTRIBUTES:{UID:aData.folder},ITEM:[aData.values]}]}];
                aRequest.ACCOUNT[0].FOLDER[0].ITEM[0].ATTRIBUTES = {action:'add'};

				delete aRequest.IMPORT[0].ACCOUNT;
			}
		}
		else
		if (aData.folder)
			aRequest.IMPORT[0].ACCOUNT[0].FOLDER = [{ATTRIBUTES:{UID:aData.folder}}];
	}


	var aResponse = this.create_iq(aRequest,'',aData.lines?'get':'set');

	var aIQ = aResponse['IQ'][0];
	if (aIQ['ATTRIBUTES']['TYPE'] == 'result') {
		if (aData.lines)
			return this.parse(aResponse);
		return true;
	}
	else
	    return false;
};

_me.parse = function(aData)
{
	try
	{
		var aFrame = aData['IQ'][0]['QUERY'][0]['IMPORT'][0]['ROW'];
		var aResult = [],tmp;
		
		for(var i in aFrame){
			tmp = [];
			for(var j in aFrame[i].COL)
				tmp.push(aFrame[i].COL[j].VALUE)

			aResult.push(tmp);
		}
		return aResult;

 	}
	catch(e){
		return false;
	}
};

==> IceWarpServer-10.1.4_RHEL5.tar.gz: html/webmail/client/inc/wm_import.js <==
function wm_import(){
	this.xmlns = 'import';
};

wm_import.inherit(wm_generic);
var _me = wm_import.prototype;

//********************************************************************************
//********************************************************************************
_me.import_data = function(aData)
{
	var aRequest = {'IMPORT':[{'ATTRIBUTES':{'ACTION':aData.action},'ACCOUNT':[{'ATTRIBUTES':{'UID':aData.account}}],'FULLPATH':[{'VALUE':aData.path}]}]};

    if (aData.action != 'groupware'){
		//Lines in case of CSV
		if (aData.action == 'csv'){
			if (aData.lines)
				aRequest.IMPORT[0].LINES = [{VALUE:aData.lines}];

			if (aData.skipfirst)
				aRequest.IMPORT[0].SKIPFIRST = [{VALUE:'true'}];

			if (aData.values){
				aRequest.ACCOUNT = [{ATTRIBUTES:{UID:aData.account},FOLDER:[{ATTRIBUTES:{UID:aData.folder},ITEM:[aData.values]}]}];
                aRequest.ACCOUNT[0].FOLDER[0].ITEM[0].ATTRIBUTES = {action:'add'};

				if (aData['share'])
                    aRequest.ACCOUNT[0].FOLDER[0].ITEM[0].VALUES[0].ITMSHARETYPE = [{VALUE:aData['share']}];

				delete aRequest.IMPORT[0].ACCOUNT;
			}
		}
		else
		if (aData.folder)
			aRequest.IMPORT[0].ACCOUNT[0].FOLDER = [{ATTRIBUTES:{UID:aData.folder}}];
	}

	var aResponse = this.create_iq(aRequest,'','',aData.lines?'get':'set');

	var aIQ = aResponse['IQ'][0];
	if (aIQ['ATTRIBUTES']['TYPE'] == 'result') {
		if (aData.lines)
			return this.parse(aResponse);
		return true;
	}
	else
	    return false;
};

_me.parse = function(aData)
{
	try
	{
		var aFrame = aData['IQ'][0]['QUERY'][0]['IMPORT'][0]['ROW'];
		var aResult = [],tmp;
		
		for(var i in aFrame){
			tmp = [];
			for(var j in aFrame[i].COL)
				tmp.push(aFrame[i].COL[j].VALUE)

			aResult.push(tmp);
		}
		return aResult;

 	}
	catch(e){
		return false;
	}
};
